# coding: utf-8
# Copyright (c) 2012-2013 Raphaël Barrois
# License: MIT
from __future__ import unicode_literals

__author__ = "Raphaël Barrois <raphael.barrois+restrictedpkg@polytechnique.org>"
__version__ = '1.1.1'

from .commands import setup
